=== modified file 'cmd/output_test.go'
--- cmd/output_test.go	2013-08-19 11:17:19 +0000
+++ cmd/output_test.go	2013-10-08 10:43:57 +0000
@@ -50,6 +50,8 @@
 	output string
 }{
 	"": {
+		{nil, ""},
+		{"", ""},
 		{1, "1\n"},
 		{-1, "-1\n"},
 		{1.1, "1.1\n"},
@@ -62,6 +64,8 @@
 		{map[interface{}]interface{}{"foo": "bar"}, "foo: bar\n"},
 	},
 	"smart": {
+		{nil, ""},
+		{"", ""},
 		{1, "1\n"},
 		{-1, "-1\n"},
 		{1.1, "1.1\n"},
@@ -74,6 +78,8 @@
 		{map[interface{}]interface{}{"foo": "bar"}, "foo: bar\n"},
 	},
 	"json": {
+		{nil, "null\n"},
+		{"", `""` + "\n"},
 		{1, "1\n"},
 		{-1, "-1\n"},
 		{1.1, "1.1\n"},
@@ -87,6 +93,8 @@
 		{defaultValue, `{"Juju":1,"Puppet":false}` + "\n"},
 	},
 	"yaml": {
+		{nil, ""},
+		{"", `""` + "\n"},
 		{1, "1\n"},
 		{-1, "-1\n"},
 		{1.1, "1.1\n"},
@@ -111,17 +119,19 @@
 			c.Logf("  test %d", i)
 			ctx := testing.Context(c)
 			result := cmd.Main(&OutputCommand{value: t.value}, ctx, args)
-			c.Assert(result, gc.Equals, 0)
-			c.Assert(bufferString(ctx.Stdout), gc.Equals, t.output)
-			c.Assert(bufferString(ctx.Stderr), gc.Equals, "")
+			c.Check(result, gc.Equals, 0)
+			c.Check(bufferString(ctx.Stdout), gc.Equals, t.output)
+			c.Check(bufferString(ctx.Stderr), gc.Equals, "")
 		}
 	}
+}
 
+func (s *CmdSuite) TestUnknownOutputFormat(c *gc.C) {
 	ctx := testing.Context(c)
 	result := cmd.Main(&OutputCommand{}, ctx, []string{"--format", "cuneiform"})
-	c.Assert(result, gc.Equals, 2)
-	c.Assert(bufferString(ctx.Stdout), gc.Equals, "")
-	c.Assert(bufferString(ctx.Stderr), gc.Matches, ".*: unknown format \"cuneiform\"\n")
+	c.Check(result, gc.Equals, 2)
+	c.Check(bufferString(ctx.Stdout), gc.Equals, "")
+	c.Check(bufferString(ctx.Stderr), gc.Matches, ".*: unknown format \"cuneiform\"\n")
 }
 
 // Py juju allowed both --format json and --format=json. This test verifies that juju is

=== modified file 'worker/uniter/jujuc/relation-get.go'
--- worker/uniter/jujuc/relation-get.go	2013-09-26 15:33:39 +0000
+++ worker/uniter/jujuc/relation-get.go	2013-10-08 10:43:57 +0000
@@ -92,11 +92,11 @@
 			return err
 		}
 	}
-	var value interface{}
 	if c.Key == "" {
-		value = settings
-	} else {
-		value, _ = settings[c.Key]
-	}
-	return c.out.Write(ctx, value)
+		return c.out.Write(ctx, settings)
+	}
+	if value, ok := settings[c.Key]; ok {
+		return c.out.Write(ctx, value)
+	}
+	return c.out.Write(ctx, nil)
 }

=== modified file 'worker/uniter/jujuc/relation-get_test.go'
--- worker/uniter/jujuc/relation-get_test.go	2013-09-12 16:29:52 +0000
+++ worker/uniter/jujuc/relation-get_test.go	2013-10-08 10:43:57 +0000
@@ -126,9 +126,14 @@
 	}, {
 		summary: "explicit smart formatting 3",
 		relid:   1,
-		args:    []string{"value", "u/1"},
+		args:    []string{"value", "u/1", "--format", "smart"},
 		out:     "12345",
 	}, {
+		summary: "explicit smart formatting 4",
+		relid:   1,
+		args:    []string{"missing", "u/1", "--format", "smart"},
+		out:     "",
+	}, {
 		summary: "json formatting 1",
 		relid:   1,
 		unit:    "m/0",
@@ -146,6 +151,11 @@
 		args:    []string{"value", "u/1", "--format", "json"},
 		out:     `"12345"`,
 	}, {
+		summary: "json formatting 4",
+		relid:   1,
+		args:    []string{"missing", "u/1", "--format", "json"},
+		out:     `null`,
+	}, {
 		summary: "yaml formatting 1",
 		relid:   1,
 		unit:    "m/0",
@@ -162,6 +172,11 @@
 		relid:   1,
 		args:    []string{"value", "u/1", "--format", "yaml"},
 		out:     `"12345"`,
+	}, {
+		summary: "yaml formatting 4",
+		relid:   1,
+		args:    []string{"missing", "u/1", "--format", "yaml"},
+		out:     ``,
 	},
 }
 
@@ -173,18 +188,18 @@
 		c.Assert(err, gc.IsNil)
 		ctx := testing.Context(c)
 		code := cmd.Main(com, ctx, t.args)
-		c.Assert(code, gc.Equals, t.code)
+		c.Check(code, gc.Equals, t.code)
 		if code == 0 {
-			c.Assert(bufferString(ctx.Stderr), gc.Equals, "")
+			c.Check(bufferString(ctx.Stderr), gc.Equals, "")
 			expect := t.out
 			if expect != "" {
 				expect = expect + "\n"
 			}
-			c.Assert(bufferString(ctx.Stdout), gc.Equals, expect)
+			c.Check(bufferString(ctx.Stdout), gc.Equals, expect)
 		} else {
-			c.Assert(bufferString(ctx.Stdout), gc.Equals, "")
+			c.Check(bufferString(ctx.Stdout), gc.Equals, "")
 			expect := fmt.Sprintf(`(.|\n)*error: %s\n`, t.out)
-			c.Assert(bufferString(ctx.Stderr), gc.Matches, expect)
+			c.Check(bufferString(ctx.Stderr), gc.Matches, expect)
 		}
 	}
 }

